aboutsummaryrefslogtreecommitdiffstats
path: root/yage/yage.h
diff options
context:
space:
mode:
Diffstat (limited to 'yage/yage.h')
-rw-r--r--yage/yage.h17
1 files changed, 7 insertions, 10 deletions
diff --git a/yage/yage.h b/yage/yage.h
index f20aff06..4fce87dc 100644
--- a/yage/yage.h
+++ b/yage/yage.h
@@ -26,15 +26,10 @@
#include "base/vertex.h"
#include "base/window.h"
+#include "physics/body.h"
+#include "physics/particlebody.h"
#include "physics/rectanglecollider.h"
#include "physics/rigidbody.h"
-#include "physics/particlebody.h"
-#include "physics/body.h"
-
-
-#include <SDL2/SDL.h>
-
-#include <stdexcept>
/** Project namespace.
*
@@ -44,17 +39,19 @@
namespace yage
{
+extern void glfwErrorCallback(int, const char *);
+
/** Initializes yage.
*
* This is only there to initialize SDL2.
*
* @return Returns true if the initialization was successful.
*/
-extern bool init();
+extern void init();
/** Quit and cleanup yage
*
* SDL2 needs to clean itself up.
*/
extern void quit();
@@ -44,17 +39,19 @@
/** Initializes yage.
*
- * This is only there to initialize SDL2.
+ * This is only there to initialize glfw.
*
* @return Returns true if the initialization was successful.
@@ -44,17 +39,19 @@
/** Quit and cleanup yage
*
- * SDL2 needs to clean itself up.
+ * glfw needs to clean itself up.
*/
extern void quit();